@@ -8,6 +8,7 @@ import pandas as pd
 from sklearn.base import BaseEstimator, RegressorMixin
 from sklearn.utils.validation import check_X_y, check_array, check_is_fitted
 from sklearn.metrics import r2_score
+from sklearn.metrics import mean_squared_error
 
 # User
 from ..utils.exceptions import WrongInputException
@@ -20,6 +21,9 @@ from ..utils.exceptions import WrongInputException
 # Constrained OLS
 #------------------------------------------------------------------------------
 class ConstrainedOLS(BaseEstimator, RegressorMixin):
+    """
+    Read about solvers: https://www.cvxpy.org/tutorial/advanced/index.html?highlight=scs#choosing-a-solver
+    """
     # --------------------
     # Constructor function
     # --------------------
@@ -50,14 +54,15 @@ class ConstrainedOLS(BaseEstimator, RegressorMixin):
     UPPER_CONSTRAINTS_ALLOWED = ["<=", "<"]
     SUM_CONSTRAINTS_ALLOWED = ["==", ">=", ">","<=", "<"]
 
+    # --------------------
+    # Private
+    # --------------------
+    def _score(self, y_true, y_pred):
+        return mean_squared_error(y_true, y_pred)
+
     # --------------------
     # Public functions
     # --------------------
-    # def get_params(self, deep=True):
-    #     pass
-    # def set_params(self):
-    #     pass
-
     def fit(self, X, y):
         
         # Check that X and y have correct shape
@@ -124,12 +129,21 @@ class ConstrainedOLS(BaseEstimator, RegressorMixin):
         # Set up ojective function
         objective = cp.Minimize(cp.sum_squares(y - X @ beta))
         
-        # Instantiate and solve
-        optim_problem = cp.Problem(objective=objective, constraints=constraints).solve(verbose=self.verbose)
+        # Instantiate
+        problem = cp.Problem(objective=objective, constraints=constraints)
+        
+        # Solve
+        problem.solve(solver=cp.SCS, verbose=self.verbose)
         
         # Beta hat
         self.beta_ = beta.value
         
+        # Fitted valued
+        self.y_fitted_ = X @ self.beta_
+
+        # Return mean squared error
+        self.best_score_ = self._score(y_true=y, y_pred=self.y_fitted_)
+        
         return self
         
         
@@ -149,7 +163,8 @@ class ConstrainedOLS(BaseEstimator, RegressorMixin):
         return y_hat
 
     def score(self, X, y, sample_weight=None):
-
+        # Predict
         y_pred = self.predict(X)
-        return r2_score(y, y_pred, sample_weight=sample_weight)
+        
+        return self._score(y_true=y, y_pred=y_pred)
         
\ No newline at end of file
